Welcome to Django Stories’s documentation! — Django Stories 1.0 documentation

Django Stories 1.0 documentation

# Welcome to Django Stories’s documentation!

- Table of Contents
- index
  modules
  next

# Welcome to Django Stories’s documentation!

This app is designed to be flexible to configure, but still simple to the writers and editors.

# Design Goals

- Reduced dependencies: Checks for optional packages and only creates the fields if they are there.
- Rich content embedding from GUI: For embedded content, the markup language’s GUI can do everything it needs.
- Flexible dependencies: Can pick from several applications that provide similar service, for example django-staff vs. User, massmedia vs. photologue

# Features

- Revision tracking: Keeps track of saved versions and allows a user to revert to a previous version.
- Related items: Can set any configured item to be related to the story. These are for Photos, Videos, other stories, etc.
- Quick Edit: Several fields can be changed in the list view including Headline, Subheadline, Teaser, Kicker and Published Status. A form is used and can be overridden by your project to include what ever fields you want.
- Optional 404 supressing: Sometimes you may have to take down content. You can now return a page with an explanation instead of returning a 404 error.

## Contents:

- Installation
  - Using PIP
  - Download
  - Install
  - Requirements
  - Run syncdb
- Upgrading to 1.0
  - Ensureing story models are correctly configured
  - Ensuring functionality
- Custom Author Model Guide
- Settings
  - STATUS_CHOICES
  - DEFAULT_STATUS
  - PUBLISHED_STATUS
  - ORIGIN_CHOICES
  - DEFAULT_ORIGIN
  - INCLUDE_PRINT
  - RELATION_MODELS
  - PAGINATION
  - THROW_404
  - AUTHOR_MODEL
  - AUTHOR_MODEL_LIMIT_CHOICES
  - USE_REVERSION
  - ORDERING
  - WIDGET
  - WIDGET_ATTRS
  - ADMIN_EXTRAS
- Pagination
  - PAGINATION settings
  - Using pagination in templates
- Integration with Other Django Applications
  - Integrating with Django Categories
  - Integrating with Django Reversion
  - Integrating with Django TinyMCE
- Reference Manual
  - Models
  - Views
  - Paginator
  - Template Tags
  - Urls

# Helping Out

- Source
- Issues

# Indices and tables

- Index
- Module Index
- Search Page